@@ -20,16 +20,31 @@ package com.beust.jcommander.args;
 
 import com.beust.jcommander.Parameter;
 import com.beust.jcommander.converters.FileConverter;
+import com.beust.jcommander.converters.PathConverter;
+import com.beust.jcommander.converters.URIConverter;
+import com.beust.jcommander.converters.URLConverter;
 
 import java.io.File;
 import java.math.BigDecimal;
+import java.net.URI;
+import java.net.URL;
+import java.nio.file.Path;
 import java.util.List;
 
 public class ArgsConverter {
 
   @Parameter(names = "-file", converter = FileConverter.class)
   public File file;
-
+  
+  @Parameter(names = "-url", converter = URLConverter.class)
+  public URL url;
+  
+  @Parameter(names = "-uri", converter = URIConverter.class)
+  public URI uri;
+  
+  @Parameter(names = "-path", converter = PathConverter.class)
+  public Path path;
+  
   @Parameter(names = "-listStrings")
   public List<String> listStrings;
 
@@ -38,4 +53,5 @@ public class ArgsConverter {
 
   @Parameter(names = "-listBigDecimals")
   public List<BigDecimal> listBigDecimals;
+  
 }
